package com.move4mobile.smartpinsdkexample

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.move4mobile.smartpinsdk.SmartPinManager
import com.move4mobile.smartpinsdk.models.SPBluetoothDevice
import com.move4mobile.smartpinsdkexample.databinding.ListItemDiscoveredTerminalBinding
import kotlinx.android.synthetic.main.activity_dicovery_terminals.*

class DiscoveredTerminalsActivity : AppCompatActivity() {

    private var terminals = mutableListOf<SPBluetoothDevice>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_dicovery_terminals)

        swipe_refresh.setOnRefreshListener {
            loadAdapter()
        }

        terminals_list.layoutManager = LinearLayoutManager(this)
        terminals_list.adapter = TerminalsAdapter(terminals)

        loadAdapter()
    }

    private fun loadAdapter() {
        swipe_refresh.isRefreshing = false

        terminals.clear()
        terminals.addAll(SmartPinManager.getConnectedTerminals(this))
        terminals_list.adapter?.notifyDataSetChanged()

        if (terminals.size == 0) {
            message.visibility = View.VISIBLE
            terminals_list.visibility = View.GONE
        } else {
            message.visibility = View.GONE
            terminals_list.visibility = View.VISIBLE
        }
    }

    inner class TerminalsAdapter(private val items: List<SPBluetoothDevice>) : RecyclerView.Adapter<TerminalsAdapter.ViewHolder>() {

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
            val binding = ListItemDiscoveredTerminalBinding.inflate(LayoutInflater.from(parent.context), parent, false)
            return ViewHolder(binding)
        }

        override fun getItemCount(): Int = items.size

        override fun onBindViewHolder(holder: ViewHolder, position: Int) = holder.bind(items[position])

        inner class ViewHolder(private val binding: ListItemDiscoveredTerminalBinding) : RecyclerView.ViewHolder(binding.root) {
            fun bind(item: SPBluetoothDevice) {
                binding.name = item.name
                binding.address = item.address
                binding.mainLayout.setOnClickListener {
                    SmartPinManager.connectDevice(it.context, item)
                    finish()
                }
            }
        }
    }
}

