package com.move4mobile.smartpinsdkexample

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.move4mobile.smartpinsdk.SmartPinManager
import com.move4mobile.smartpinsdk.interfaces.SPOrdersListener
import com.move4mobile.smartpinsdk.models.SPError
import com.move4mobile.smartpinsdk.models.SPOrder
import com.move4mobile.smartpinsdkexample.databinding.ListItemOrderBinding
import kotlinx.android.synthetic.main.activity_orders.*
import java.math.BigDecimal
import java.text.DecimalFormat
import java.text.NumberFormat
import java.text.SimpleDateFormat
import java.util.*

class OrdersActivity : AppCompatActivity() {

    private var orders = mutableListOf<SPOrder>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_orders)

        val calendar = Calendar.getInstance()
        calendar.time = Date()
        calendar.add(Calendar.MONTH, -3);
        val startDate = calendar.time

        SmartPinManager.getOrders(startDate, null, object : SPOrdersListener {
            override fun onOrdersReceived(orderList: List<SPOrder>) {
                orders.clear()
                orders.addAll(orderList)
                updateAdapter()
            }

            override fun onOrdersFailed(error: SPError) {
                Log.d(SmartPinManager.TAG, "Orders failed: ${error.message}")
                updateAdapter()
            }
        })

        orders_list.layoutManager = LinearLayoutManager(this)
        orders_list.adapter = OrdersAdapter(orders)

        swipe_refresh.isRefreshing
        swipe_refresh.setOnRefreshListener {
            updateAdapter()
        }

        loader.visibility = View.VISIBLE
        message.visibility = View.GONE
        orders_list.visibility = View.GONE
    }

    private fun updateAdapter() {
        swipe_refresh.isRefreshing = false

        loader.visibility = View.GONE

        orders_list.adapter?.notifyDataSetChanged()

        if (orders.size == 0) {
            message.visibility = View.VISIBLE
            orders_list.visibility = View.GONE
        } else {
            message.visibility = View.GONE
            orders_list.visibility = View.VISIBLE
        }
    }

    fun priceToString(price: BigDecimal): String? {
        var decimalFormat: DecimalFormat? = null

        val numberFormat = NumberFormat.getNumberInstance(Locale.getDefault())
        decimalFormat = (numberFormat as DecimalFormat)
        decimalFormat.maximumFractionDigits = 2
        decimalFormat.minimumFractionDigits = 2
        decimalFormat.isGroupingUsed = false

        return decimalFormat.format(price.setScale(2, BigDecimal.ROUND_HALF_UP))
    }

    inner class OrdersAdapter(private val items: List<SPOrder>) : RecyclerView.Adapter<OrdersAdapter.ViewHolder>() {

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
            val binding = ListItemOrderBinding.inflate(LayoutInflater.from(parent.context), parent, false)
            return ViewHolder(binding)
        }

        override fun getItemCount(): Int = items.size

        override fun onBindViewHolder(holder: ViewHolder, position: Int) = holder.bind(items[position])

        inner class ViewHolder(private val binding: ListItemOrderBinding) : RecyclerView.ViewHolder(binding.root) {
            fun bind(item: SPOrder) {
                val date = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss", Locale.getDefault()).parse(item.date)
                val convertedDateFormat = SimpleDateFormat("dd-MM-yyyy", Locale.getDefault())
                binding.id = item.id.toString()
                binding.date = convertedDateFormat.format(date ?: "")
                binding.type = item.type.toString()
                binding.price = "€ ${priceToString(item.amount)}"
                binding.mainLayout.setOnClickListener {
                    val intent = Intent(binding.root.context, OrderActivity::class.java)
                    intent.putExtra(OrderActivity.ORDER_ID, item.id)
                    startActivity(intent)
                }
            }
        }
    }
}