package com.move4mobile.smartpinsdkexample

import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.move4mobile.smartpinsdk.SmartPinManager
import com.move4mobile.smartpinsdk.interfaces.SPSitesListener
import com.move4mobile.smartpinsdk.models.SPError
import com.move4mobile.smartpinsdk.models.SPSite
import com.move4mobile.smartpinsdkexample.databinding.ListItemSiteBinding
import kotlinx.android.synthetic.main.activity_sites.*

class SitesActivity : AppCompatActivity() {

    private var sites = mutableListOf<SPSite>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_sites)

        SmartPinManager.getSites(object : SPSitesListener {
            override fun onSitesReceived(sitesList: List<SPSite>) {
                sites.clear()
                sites.addAll(sitesList)
                updateAdapter()
            }

            override fun onSitesFailed(error: SPError) {
                Log.d(SmartPinManager.TAG, "Sites failed: ${error.message}")
                updateAdapter()
            }
        })

        sites_list.layoutManager = LinearLayoutManager(this)
        sites_list.adapter = SitesAdapter(sites)

        swipe_refresh.isRefreshing
        swipe_refresh.setOnRefreshListener {
            updateAdapter()
        }

        loader.visibility = View.VISIBLE
        message.visibility = View.GONE
    }

    private fun updateAdapter() {
        swipe_refresh.isRefreshing = false

        loader.visibility = View.GONE

        sites_list.adapter?.notifyDataSetChanged()

        if (sites.size == 0) {
            message.visibility = View.VISIBLE
            sites_list.visibility = View.GONE
        } else {
            message.visibility = View.GONE
            sites_list.visibility = View.VISIBLE
        }
    }

    inner class SitesAdapter(private val items: List<SPSite>) : RecyclerView.Adapter<SitesAdapter.ViewHolder>() {

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
            val binding = ListItemSiteBinding.inflate(LayoutInflater.from(parent.context), parent, false)
            return ViewHolder(binding)
        }

        override fun getItemCount(): Int = items.size

        override fun onBindViewHolder(holder: ViewHolder, position: Int) = holder.bind(items[position])

        inner class ViewHolder(private val binding: ListItemSiteBinding) : RecyclerView.ViewHolder(binding.root) {
            fun bind(item: SPSite) {
                binding.id = item.externalId
                binding.name = if(item.name.isNullOrEmpty()) item.externalId else item.name
                binding.terminals = item.terminals.size.toString()
            }
        }
    }

}