package com.move4mobile.smartpinsdkexample

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.move4mobile.smartpinsdk.SmartPinManager
import com.move4mobile.smartpinsdk.interfaces.SPTerminalsListener
import com.move4mobile.smartpinsdk.models.SPError
import com.move4mobile.smartpinsdk.models.SPTerminal
import com.move4mobile.smartpinsdkexample.databinding.ListItemTerminalBinding
import kotlinx.android.synthetic.main.activity_terminals.*

class TerminalsActivity : AppCompatActivity() {

    private var terminals = mutableListOf<SPTerminal>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_terminals)

        SmartPinManager.getTerminals(object : SPTerminalsListener {
            override fun onTerminalsReceived(terminalsList: List<SPTerminal>) {
                terminals.clear()
                terminals.addAll(terminalsList)
                updateAdapter()
            }

            override fun onTerminalsFailed(error: SPError) {
                Log.d(SmartPinManager.TAG, "Terminals failed: ${error.message}")
                updateAdapter()
            }

        })

        terminals_list.layoutManager = LinearLayoutManager(this)
        terminals_list.adapter = TerminalsAdapter(terminals)

        swipe_refresh.isRefreshing
        swipe_refresh.setOnRefreshListener {
            updateAdapter()
        }

        loader.visibility = View.VISIBLE
        message.visibility = View.GONE
    }

    private fun updateAdapter() {
        swipe_refresh.isRefreshing = false

        loader.visibility = View.GONE

        terminals_list.adapter?.notifyDataSetChanged()

        if (terminals.size == 0) {
            message.visibility = View.VISIBLE
            terminals_list.visibility = View.GONE
        } else {
            message.visibility = View.GONE
            terminals_list.visibility = View.VISIBLE
        }
    }

    inner class TerminalsAdapter(private val items: List<SPTerminal>) : RecyclerView.Adapter<TerminalsAdapter.ViewHolder>() {

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
            val binding = ListItemTerminalBinding.inflate(LayoutInflater.from(parent.context), parent, false)
            return ViewHolder(binding)
        }

        override fun getItemCount(): Int = items.size

        override fun onBindViewHolder(holder: ViewHolder, position: Int) = holder.bind(items[position])

        inner class ViewHolder(private val binding: ListItemTerminalBinding) : RecyclerView.ViewHolder(binding.root) {
            fun bind(item: SPTerminal) {
                binding.externalId = item.externalId
            }
        }
    }

}